==> antwar-highlight-plugin-0.2.1.tgz: package/index.js <==
'use strict';

module.exports = function(o) {
  var style = o.style || noop;

  return {
    bodyContent: function(options) {
      style();

      var React = require('react');

      return React.createClass({
        render: function () {
          return null;
        }
      });
    },
    postProcessItems: function(items) {
      var Prism = require('prismjs');
      var languages = require('prism-languages');
      var highlight = Prism.highlight;
      var _ = require('lodash');
      var he = require('he');
      var cheerio = require('cheerio');

      _.each(items, function (item) {
        if(!item.content) {
          return;
        }

        var $ = cheerio.load(item.content);

        $('code').replaceWith(function(i, e) {
            var defaultLanguage = 'bash';
            var $e = $(e);
            var text = $e.text();
            var language = $e.attr('class');
            var result;

            if(language) {
              language = language.split('-');
              language = language.length > 1 ? language[1] : defaultLanguage;
            }
            else {
              return $('<code>' + he.encode(text) + '</code>');
            }

            if(language === 'html') {
              language = 'markup';
            }

            if(!languages[language]) {
              console.warn('Failed to find language definition', language);

              return $('<code>' + he.encode(text) + '</code>');
            }

            try {
              result = highlight($e.text(), languages[language]);
            }
            catch(e) {
              console.warn('Failed to highlight, defaulting to', defaultLanguage);

              result = highlight($e.text(), languages[defaultLanguage]);
            }

            return $e.html(result);
        });

        item.content = $.html();
      });

      return items;
    }
  };
};

function noop() {}

==> antwar-highlight-plugin-0.2.2.tgz: package/index.js <==
'use strict';

module.exports = function(o) {
  var style = o.style || noop;

  return {
    bodyContent: function(options) {
      style();

      var React = require('react');

      return React.createClass({
        render: function () {
          return null;
        }
      });
    },
    postProcessItems: function(items) {
      var Prism = require('prismjs');
      var languages = require('prism-languages');
      var highlight = Prism.highlight;
      var _ = require('lodash');
      var he = require('he');
      var cheerio = require('cheerio');

      _.each(items, function (item) {
        if(!item.content) {
          return;
        }

        var $ = cheerio.load(item.content);

        $('code').replaceWith(function(i, e) {
            var defaultLanguage = 'markup';
            var $e = $(e);
            var text = $e.text();
            var language = $e.attr('class');
            var result;

            if(language) {
              language = language.split('-');
              language = language.length > 1 ? language[1] : defaultLanguage;
            }
            else {
              return $('<code>' + he.encode(text) + '</code>');
            }

            if(language === 'html') {
              language = 'markup';
            }

            if(!languages[language]) {
              console.warn('Failed to find language definition', language);

              return $('<code>' + he.encode(text) + '</code>');
            }

            try {
              result = highlight($e.text(), languages[language]);
            }
            catch(e) {
              console.warn('Failed to highlight, defaulting to', defaultLanguage);

              result = highlight($e.text(), languages[defaultLanguage]);
            }

            return $e.html(result);
        });

        item.content = $.html();
      });

      return items;
    }
  };
};

function noop() {}
